=========================
Contributor Documentation
=========================

.. toctree::
   :maxdepth: 2

   architecture
   devstack-installation
   ../specs/index
   devref/index


Communication and Meetings
==========================

- Karbor Launchpad Link: \ https://launchpad.net/karbor
- Karbor Code Review: \ https://review.openstack.org/#/q/karbor+status:open,n,z
- Karbor Code Repository: \ https://github.com/openstack/karbor
- Karbor daily IRC Channel: #openstack-karbor
- Karbor IRC Meeting: every two weeks (on odd weeks) on Tuesday at 0900 UTC in
  #openstack-meeting (IRC webclient).

  ICS File: http://eavesdrop.openstack.org/calendars/karbor-team-meeting.ics

  Additional Info: https://wiki.openstack.org/wiki/Meetings/karbor

Plugins Development Guide
=========================
.. toctree::
   :maxdepth: 1

   bank_plugins_guide
   protectable_plugins_guide
   protection_plugins_guide

Additional References
=====================

- `OpenStack Tokyo Summit 2015 talk <http://www.slideshare.net/gampel/openstack-tokyo-talk-application-data-protection-service>`_
- `OpenStack Austin Summit 2016 talk <https://www.youtube.com/watch?v=_tVYuW_YMB8>`_
- `OpenStack Barcelona Summit 2016 talk <https://www.youtube.com/watch?v=YFfcmGMn3M4>`_
- `OpenStack Boston Summit 2017 talk <https://www.youtube.com/watch?v=0l3zcmNboDQ>`_
- `Karbor overview slide <https://docs.google.com/presentation/d/1JYO1VIlTkGTF6lvKEMcsHkaST3mYFxuarpcNTJ3HBhk/edit?usp=sharing>`_
- `Karbor overview blog  <http://blog.gampel.net/2015/12/karbor-application-data-protection-for.html>`_
